<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://madebytribe.com
 * @since      1.0.0
 *
 * @package    Klaviyo_Toolkit
 * @subpackage Klaviyo_Toolkit/admin
 */

class KT_Admin {
	
	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;
	
	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
	
	/**
	 * The KT_WC_Sub_Exporter instance.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      KT_WC_Sub_Exporter    $kt_export    The instance of the KT_WC_Sub_Exporter class.
	 */
	private $kt_export;
	
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
	
		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		// Initialize the KT_WC_Sub_Exporter class
		$this->initialize_export();
		
		add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'plugin_settings_link'));
		
		add_action( 'admin_init', array( 'PAnD', 'init' ) );
	
	}
	
	/**
	 * Initialize the KT_WC_Sub_Exporter class.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function initialize_export() {
		require_once plugin_dir_path(__FILE__) . '../includes/class-kt-wc-sub-exporter.php';
		$this->kt_export = new KT_WC_Sub_Exporter();
	}
	
	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles($hook) {
	
		if (isset($_GET['page']) && 'klaviyo-toolkit' === $_GET['page']) {
			wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/kt-admin.css', array(), $this->version, 'all' );
			wp_enqueue_style('kt-admin-notices', plugin_dir_url(__FILE__) . 'css/kt-admin-notices.css');
			wp_enqueue_style('select2-css', 'https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/css/select2.min.css', array(), '4.1.0');
		}
	
	}
	
	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
	
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/kt-admin.js', array( 'jquery' ), $this->version, true );
		
		$params = array(
			'ajaxurl' => admin_url('admin-ajax.php'),
		);
		
		wp_localize_script( $this->plugin_name, 'klaviyoAdminAjax', $params);
		wp_enqueue_script('select2', 'https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/js/select2.min.js', array('jquery'), '4.1.0', true);
	
	}
	
	/**
	 * Check license status in admin license page
	 */
	public function klaviyo_toolkit_edd_license_check() {
	
		// Check EDD license on KT settings or license pages
		if ( isset( $_GET['page'] ) && ( 'klaviyo-toolkit' === $_GET['page'] ) ) {
			// retrieve our license key from the DB
			$license_key = trim( get_option( 'klaviyo_edd_license_key' ) );
	
			// Yearly product response and license data
			$api_params = array(
				'edd_action' => 'check_license',
				'license'    => $license_key,
				'item_id'    => KLAVIYO_TOOLKIT_EDD_ITEM_ID,
				'url'        => home_url(),
			);
	
			// Call the custom API.
			$edd_item_response = wp_remote_post( KLAVIYO_TOOLKIT_EDD_STORE_URL, array( 'timeout' => 15, 'sslverify' => true, 'body' => $api_params ) );
			$license_data      = json_decode( wp_remote_retrieve_body( $edd_item_response ) );
	
			if ( 'valid' === $license_data->license ) {
				// this license is valid
				update_option( 'klaviyo_edd_license_status', 'valid' );
			} else {
				// this license is no longer valid
				update_option( 'klaviyo_edd_license_status', 'invalid' );
			}
		}
	}

	public function plugin_settings_link($links) {
		$url = get_admin_url() . 'admin.php?page=klaviyo-toolkit';
		$settings_link = '<a href="' . $url . '">' . __('Settings', 'klaviyo-toolkit') . '</a>';
		array_unshift($links, $settings_link);

		return $links;
	}

	public function add_admin_menu() {
		add_menu_page(
			__('Klaviyo Toolkit', 'klaviyo-toolkit'),
			__('Klaviyo Toolkit', 'klaviyo-toolkit'),
			'manage_options',
			'klaviyo-toolkit',
			array($this, 'kt_admin_menu'),
			'dashicons-email-alt'
		);
	}

	public function kt_admin_menu() {
		require plugin_dir_path(__FILE__) . 'partials/kt-admin-settings-tab.php';
	}

}
