<?php

/**
 * All EDD license related options, variables & functions stored here now.
 *
 * @package    klaviyo-toolkit
 * @subpackage klaviyo-toolkit/includes
 * @author     Tribe Interactive <hello@madebytribe.com>
 */
class KT_EDD_License {

	private $loader;
	private $license_key;
	private $item_name;
	private $item_id;
	private $api_url;
	private $version;
	private $author;

	public function __construct( $loader ) {
		$this->loader      = $loader;
		$this->license_key = trim( get_option( 'klaviyo_edd_license_key' ) );
		$this->item_name   = KLAVIYO_TOOLKIT_EDD_ITEM_NAME;
		$this->item_id     = KLAVIYO_TOOLKIT_EDD_ITEM_ID;
		$this->api_url     = KLAVIYO_TOOLKIT_EDD_STORE_URL;
		$this->version     = KLAVIYO_TOOLKIT_VERSION;
		$this->author      = KLAVIYO_TOOLKIT_AUTHOR;
	}

	public function register_hooks() {

		// Add the license check only if we're on the settings page
		if (isset($_GET['page']) && 'klaviyo-toolkit' === $_GET['page']) {
			$this->loader->add_action('admin_init', $this, 'kt_check_license');
		}

	}

	public function kt_activate_license() {
		$button_name = ! empty( $_POST['button_name'] ) ? $_POST['button_name'] : '';

		// listen for our activate button to be clicked
		if ( 'klaviyo_edd_license_activate' === $button_name ) {

			// retrieve the license from the database
			$klaviyo_edd_license_key = trim( get_option( 'klaviyo_edd_license_key' ) );

			// data to send in our API request
			$api_params = array(
				'edd_action' => 'activate_license',
				'license'    => $klaviyo_edd_license_key,
				'item_id'    => $this->item_id, // The ID of the item in EDD
				'url'        => home_url(),
			);

			// Call the custom API.
			$response     = wp_remote_post( $this->api_url, array( 'timeout' => 15, 'sslverify' => true, 'body' => $api_params ) );
			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			// make sure the response came back okay
			if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {
				$message = ( is_wp_error( $response ) && ! empty( $response->get_error_message() ) ) ? $response->get_error_message() : __( 'An error occurred, please try again.', 'kl-coupons' );
			} else {
				if ( false === $license_data->success ) {
					switch ( $license_data->error ) {
						case 'expired' :
							$message = sprintf(
								__( 'Your license key expired on %s.' ),
								date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) )
							);
							break;
						case 'revoked' :
							$message = __( 'Your license key has been disabled.' );
							break;
						case 'missing' :
							$message = __( 'Invalid license.' );
							break;
						case 'invalid' :
						case 'site_inactive' :
							$message = __( 'Your license is not active for this URL.' );
							break;
						case 'item_name_mismatch' :
							$message = sprintf( __( 'This appears to be an invalid license key for %s.' ), $this->item_name );
							break;
						case 'no_activations_left':
							$message = __( 'Your license key has reached its activation limit.' );
							break;
						default :
							$message = __( 'An error occurred, please try again.' );
							break;
					}
				}
			}

			// Check if anything passed on a message constituting a failure
			if ( ! empty( $message ) ) {
				$base_url = admin_url( 'admin.php?page=klaviyo-toolkit&tab=license' );
				// Redirect url are returned
				$data = array(
					'redirect_url'  => $base_url,
					'sl_activation' => 'false',
					'message'       => $message,
				);
				wp_send_json( $data );
			}

			// $license_data->license will be either "valid" or "invalid"
			update_option( 'klaviyo_edd_license_status', $license_data->license );

			// Redirect url are returned
			$data = array(
				'redirect_url'  => admin_url( 'admin.php?page=klaviyo-toolkit&tab=license' ),
				'sl_activation' => 'true',
				'message'       => __( 'License successfully activated', 'kl-coupons' ),
			);
			wp_send_json( $data );

		} else if ( 'klaviyo_edd_license_deactivate' === $button_name ) {

			// retrieve the license from the database
			$klaviyo_edd_license_key = trim( get_option( 'klaviyo_edd_license_key' ) );

			// data to send in our API request
			$api_params = array(
				'edd_action' => 'deactivate_license',
				'license'    => $klaviyo_edd_license_key,
				'item_name'  => urlencode( $this->item_name ), // the name of our product in EDD
				'url'        => home_url(),
			);

			// Call the custom API.
			$response = wp_remote_post( $this->api_url, array( 'timeout' => 15, 'sslverify' => true, 'body' => $api_params ) );

			// make sure the response came back okay
			if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {
				if ( is_wp_error( $response ) ) {
					$message = $response->get_error_message();
				} else {
					$message = __( 'An error occurred, please try again.' );
				}
				$base_url = admin_url( 'admin.php?page=klaviyo-toolkit&tab=license' );
				// Redirect url are returned
				$data = array(
					'redirect_url'  => $base_url,
					'sl_activation' => 'false',
					'message'       => $message,
				);
				wp_send_json( $data );
			}

			// decode the license data
			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			// $license_data->license will be either "deactivated" or "failed"
			if ( $license_data->license == 'deactivated' || $license_data->license == 'failed' ) {
				delete_option( 'klaviyo_edd_license_status' );
			}

			// Redirect url are returned
			$data = array(
				'redirect_url'  => admin_url( 'admin.php?page=klaviyo-toolkit&tab=license' ),
				'sl_activation' => 'true',
				'message'       => __( 'License deactivated', 'klaviyo-toolkit' ),
			);
			wp_send_json( $data );
		}
		wp_die();
	}

	public function kt_check_license() {
		
		// Check if we recently checked the license
		$license_status = get_option('klaviyo_edd_license_status');
		$last_checked = get_option('klaviyo_edd_license_last_checked');
	
		if ($last_checked && (time() - $last_checked < DAY_IN_SECONDS)) {
			// Only check if it has been more than a day since the last check
			return;
		}
	
		$api_params = array(
			'edd_action' => 'check_license',
			'license'    => $this->license_key,
			'item_id'    => $this->item_id,
			'url'        => home_url(),
		);
	
		// Call the custom API.
		$edd_item_response = wp_remote_post($this->api_url, array('timeout' => 15, 'sslverify' => true, 'body' => $api_params));
		$license_data = json_decode(wp_remote_retrieve_body($edd_item_response));
	
		if ('valid' === $license_data->license) {
			// This license is valid
			update_option('klaviyo_edd_license_status', 'valid');
		} else {
			// This license is no longer valid
			update_option('klaviyo_edd_license_status', 'invalid');
		}
	
		// Update the last checked time
		update_option('klaviyo_edd_license_last_checked', time());
		
	}

}
