<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class KT_WC_Sub_Exporter {
	private $batch_size = 500; // Define the batch size as a class property

	public function __construct() {
		add_action('wp_ajax_download_wc_subscriptions', array($this, 'ajax_download_wc_subscriptions'));
		add_action('wp_ajax_get_export_progress', array($this, 'ajax_get_export_progress'));
		add_action('wp_ajax_get_exported_file_url', array($this, 'ajax_get_exported_file_url'));
		add_action('wp_ajax_finish_export', array($this, 'finish_export_callback'));
		
		// Get subscription products for exporter
		add_action('wp_ajax_get_subscription_products', array($this,  'get_subscription_products'));
	}

	private function initialize_export($selected_products = []) {		
		// Clear existing transients before setting new values
		delete_transient('all_subscription_product_ids');
		delete_transient('kt_export_filename');
	
		// Continue with setting up the new export
		$upload_dir = wp_upload_dir();
		$kt_exports_dir = trailingslashit($upload_dir['basedir']) . 'kt-exports/';
		if (!file_exists($kt_exports_dir)) {
			wp_mkdir_p($kt_exports_dir);
		}
		$file_name = $kt_exports_dir . 'wc-sub-status-export-' . current_time('YmdHis') . '.csv';
		set_transient('kt_export_filename', $file_name, 10 * MINUTE_IN_SECONDS);
	
		$this->set_all_subscription_product_ids($selected_products);
		$this->write_headers_to_csv();
	
		if (false === get_transient('subscription_export_progress')) {
			set_transient('subscription_export_progress', 0, 10 * MINUTE_IN_SECONDS);
		}
	}

	private function fetch_subscriptions($offset = 0) {
		$data = [];
		$processed_in_batch = 0;
		$args = [
			'subscriptions_per_page' => $this->batch_size,
			'offset' => $offset,
			'orderby' => 'date',
			'order' => 'DESC'
		];
		$subscriptions = wcs_get_subscriptions($args);
	
		foreach ($subscriptions as $subscription) {
			$email = $subscription->get_billing_email();
			$items = $subscription->get_items();
			foreach ($items as $item) {
				$product_id = $item->get_product_id();
				$variation_id = $item->get_variation_id();
				$product_key = 'wc-sub-product-' . (!empty($variation_id) ? $variation_id : $product_id);
	
				// Only keep the latest subscription status for each product key
				if (!isset($data[$email][$product_key]) || strtotime($subscription->get_date_created()) > strtotime($data[$email][$product_key]['date'])) {
					$data[$email][$product_key] = [
						'status' => $subscription->get_status(),
						'date' => $subscription->get_date_created()
					];
				}
			}
		}
	
		// Prepare data for CSV export
		$export_data = [];
		$all_product_ids = array_keys(get_transient('all_subscription_product_ids') ?: []);
	
		foreach ($data as $email => $subscriptions) {
			$row = [$email];
			$has_data = false;
			foreach ($all_product_ids as $product_id) {
				$product_key = $product_id; // Use product_id directly as received
				if (isset($subscriptions[$product_key])) {
					$row[] = $subscriptions[$product_key]['status'];
					$has_data = true;
				} else {
					$row[] = '';
				}
			}
			// Only include rows that have subscription data
			if ($has_data) {
				$export_data[] = $row;
			}
		}
	
		$this->write_batch_to_csv($export_data);
		return $processed_in_batch;
	}

	public function ajax_download_wc_subscriptions() {
		// Check for the offset in the request.
		$offset = isset($_POST['offset']) ? intval($_POST['offset']) : 0;
		$selected_products = isset($_POST['selected_products']) ? array_map('intval', $_POST['selected_products']) : [];
	
		// If offset is 0, it means this is the start of the export, so initialize.
		if ($offset === 0) {
			$this->initialize_export($selected_products);
		}
	
		// Fetch Subscriptions and write them directly to the CSV
		$batch_size = $this->fetch_subscriptions($offset);  // Assume fetch_subscriptions returns the number of subscriptions processed in the batch.
	
		// Calculate the progress.
		$query_args = [
			'post_type' => 'shop_subscription',
			'post_status' => 'any',
			'fields' => 'ids',
			'posts_per_page' => -1,
		];
		if (!empty($selected_products)) {
			$query_args['meta_query'] = [
				'relation' => 'OR',
				[
					'key' => '_product_id',
					'value' => $selected_products,
					'compare' => 'IN',
				],
				[
					'key' => '_variation_id',
					'value' => $selected_products,
					'compare' => 'IN',
				],
			];
		}
		$query = new WP_Query($query_args);
		$total_subscriptions = $query->found_posts;
	
		$processed_subscriptions = 0; // Initialize the variable
		if ($total_subscriptions > 0) {
			$processed_subscriptions = $offset + $batch_size;
			$progress = min(100, round(($processed_subscriptions / $total_subscriptions) * 100));
		} else {
			$progress = 100;
		}
	
		// Determine if more batches are needed.
		$hasMore = ($processed_subscriptions < $total_subscriptions);
	
		// Respond with progress and offset data.
		$response = array(
			'hasMore' => $hasMore,
			'nextOffset' => $offset + $this->batch_size,
			'progress' => $progress,
		);
	
		// If all subscriptions are processed, add the file URL to the response.
		if (!$hasMore) {
			$file_url = $this->convert_file_name_to_url($this->get_csv_filename());
			$response['file'] = $file_url;
			delete_transient('subscription_export_progress'); // Clear the progress once done
			delete_transient('all_subscription_product_ids'); // Also clear the product IDs transient
		}
		
		header('Content-Type: application/json');
	
		echo json_encode($response);
		wp_die();
	}

	private function get_csv_filename() {
		$file_name = get_transient('kt_export_filename');
		if (!$file_name) {
			Klaviyo_Toolkit::log_message('Exporter error: Filename transient not set!');
			return false;
		}
		return $file_name;
	}

	private function convert_file_name_to_url($file_name) {
		// Convert the file name to its respective URL for downloading
		$upload_dir = wp_upload_dir();
		$base_url = trailingslashit($upload_dir['baseurl']);
		$relative_path = str_replace($upload_dir['basedir'], '', $file_name); // Get the relative path of the file
		$file_url = $base_url . ltrim($relative_path, '/');
		return $file_url;
	}

	public function ajax_get_export_progress() {
		$progress = get_transient('subscription_export_progress');
		echo is_numeric($progress) ? $progress : 0;
		wp_die();
	}

	public function ajax_get_exported_file_url() {
		set_transient('exported_file_url', $this->convert_file_name_to_url($this->get_csv_filename()), 10 * MINUTE_IN_SECONDS);
		
		// Assuming you store the file URL in a transient or option after the export
		$file_url = get_transient('exported_file_url');
	
		if ($file_url) {
			wp_send_json_success(['file' => $file_url]);
		} else {
			Klaviyo_Toolkit::log_message('Exporter error: File not found.');
			wp_send_json_error(['message' => 'File not found.']);
		}
	}

	private function write_batch_to_csv($data) {
		$file_name = $this->get_csv_filename();
		if (!$file_name) {
			Klaviyo_Toolkit::log_message('Exporter error: CSV file name is not set.');
			return;
		}
		$file_handle = fopen($file_name, 'a');
		if (!$file_handle) {
			Klaviyo_Toolkit::log_message('Exporter error:  Cannot open file ' . $file_name);
			return;
		}
	
		foreach ($data as $row) {
			if (!fputcsv($file_handle, $row)) {
				Klaviyo_Toolkit::log_message('Exporter error: Failed to write row to CSV.');
			}
		}
		fclose($file_handle);
	}

	private function write_headers_to_csv() {
		$file_name = $this->get_csv_filename();
		if (!file_exists($file_name) || filesize($file_name) == 0) {
			$file_handle = fopen($file_name, 'w'); // 'w' mode to overwrite/create new file
			$all_product_ids = get_transient('all_subscription_product_ids'); // Get transient data
			if (!$all_product_ids) {
				Klaviyo_Toolkit::log_message('Exporter error: Product IDs transient is empty.');
				fclose($file_handle);
				return; // Exit if there's no product ID data
			}
			$headers = ['Email'];
			foreach (array_keys($all_product_ids) as $product_id) {
				$headers[] = $product_id; // Directly use product_id
			}
			fputcsv($file_handle, $headers);
			fclose($file_handle);
		}
	}

	public function finish_export_callback() {
		delete_transient('kt_export_filename');
		wp_send_json_success();
	}

	private function set_all_subscription_product_ids($selected_products = []) {
		global $wpdb;
		if (!get_transient('all_subscription_product_ids')) {
			$product_ids = [];
	
			// Fetch product and variation IDs based on selection
			if (!empty($selected_products)) {
				$product_ids = $selected_products;
				$product_ids_string = implode(',', array_map('intval', $product_ids));
				$query = "SELECT DISTINCT meta_value FROM {$wpdb->prefix}woocommerce_order_itemmeta WHERE meta_key IN ('_product_id', '_variation_id') AND meta_value IN ($product_ids_string)";
				$product_ids = $wpdb->get_col($query);
	
				// Fetch variation IDs if parent products are selected
				$variation_ids_query = "
					SELECT DISTINCT p.ID
					FROM {$wpdb->prefix}posts p
					INNER JOIN {$wpdb->prefix}postmeta pm ON p.ID = pm.post_id
					WHERE pm.meta_key = '_product_id'
					AND pm.meta_value IN ($product_ids_string)
					AND p.post_type = 'product_variation'";
				$variation_ids = $wpdb->get_col($variation_ids_query);
				$product_ids = array_merge($product_ids, $variation_ids);
			} else {
				// Fetch all product and variation IDs if no specific selection
				$query = "SELECT DISTINCT meta_value FROM {$wpdb->prefix}woocommerce_order_itemmeta WHERE meta_key IN ('_product_id', '_variation_id')";
				$product_ids = $wpdb->get_col($query);
			}
	
			$all_product_ids = array_combine(
				array_map(function ($id) { return 'wc-sub-product-' . $id; }, $product_ids),
				array_fill(0, count($product_ids), true)
			);
	
			set_transient('all_subscription_product_ids', $all_product_ids, DAY_IN_SECONDS);
		}
	}

	public function get_subscription_products() {
		if (!current_user_can('manage_options')) {
			wp_send_json_error(['message' => 'Unauthorized']);
		}
	
		$search = isset($_GET['q']) ? sanitize_text_field($_GET['q']) : '';
		$args = [
			'post_type' => 'product',
			'posts_per_page' => -1,
			's' => $search,
			'tax_query' => [
				[
					'taxonomy' => 'product_type',
					'field' => 'slug',
					'terms' => ['subscription', 'variable-subscription'],
					'operator' => 'IN'
				],
			],
		];
	
		$query = new WP_Query($args);
		$products = [];
	
		if ($query->have_posts()) {
			while ($query->have_posts()) {
				$query->the_post();
				$product_id = get_the_ID();
				$product = wc_get_product($product_id);
	
				// Add the main product
				$products[] = [
					'id' => $product_id,
					'text' => wp_strip_all_tags(get_the_title()),
				];
	
				// Add variations if it's a variable subscription product
				if ($product->is_type('variable-subscription')) {
					$variations = $product->get_available_variations();
					foreach ($variations as $variation) {
						$variation_id = $variation['variation_id'];
						$variation_product = wc_get_product($variation_id);
						$variation_name = $variation_product->get_formatted_name(); // Already includes parent name
						$products[] = [
							'id' => $variation_id,
							'text' => wp_strip_all_tags($variation_name),
						];
					}
				}
			}
		}
	
		wp_reset_postdata();
		wp_send_json_success(['results' => $products]);
	}
}
