<?php

/**
 * The file that defines the core plugin class
 *
 * @link       https://madebytribe.com
 * @since      1.0.0
 *
 * @package    Klaviyo_Toolkit
 * @subpackage Klaviyo_Toolkit/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Klaviyo_Toolkit
 * @subpackage Klaviyo_Toolkit/includes
 * @author     Tribe Interactive <hello@madebytribe.com>
 */
class Klaviyo_Toolkit {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Klaviyo_Toolkit_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'KLAVIYO_TOOLKIT_VERSION' ) ) {
			$this->version = KLAVIYO_TOOLKIT_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'klaviyo-toolkit';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Klaviyo_Toolkit_Loader. Orchestrates the hooks of the plugin.
	 * - Klaviyo_Toolkit_i18n. Defines internationalization functionality.
	 * - Klaviyo_Toolkit_Admin. Defines all hooks for the admin area.
	 * - Klaviyo_Toolkit_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-kt-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-kt-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-kt-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-kt-public.php';

		$this->loader = new Klaviyo_Toolkit_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Klaviyo_Toolkit_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Klaviyo_Toolkit_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {
		
		$plugin_license = new KT_EDD_License( $this->loader );
		$plugin_license->register_hooks();
		
		$admin_notices = new KT_Admin_Notices( $this->loader );
		$admin_notices->register_hooks();
		
		$this->loader->add_action( 'wp_ajax_kt_license_button', $plugin_license, 'kt_activate_license' );

		$plugin_admin = new KT_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_admin_menu');
		
		// Add action for cron hook to check license status
		$this->loader->add_action( 'admin_init', $plugin_admin, 'klaviyo_toolkit_edd_license_check' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new KT_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		
		$this->loader->add_action('rss2_item', $plugin_public, 'klaviyo_add_imgs_to_rss_feeds');
		$this->loader->add_action('wp_ajax_klaviyo_viewed_page', $plugin_public, 'handle_klaviyo_viewed_page');
		$this->loader->add_action('wp_ajax_nopriv_klaviyo_viewed_page', $plugin_public, 'handle_klaviyo_viewed_page');
		$this->loader->add_action('wp_ajax_klaviyo_searched_site', $plugin_public, 'handle_klaviyo_searched_site');
		$this->loader->add_action('wp_ajax_nopriv_klaviyo_searched_site', $plugin_public, 'handle_klaviyo_searched_site');
		$this->loader->add_action('wp_ajax_klaviyo_viewed_pro_cat', $plugin_public, 'handle_klaviyo_viewed_pro_cat');
		$this->loader->add_action('wp_ajax_nopriv_klaviyo_viewed_pro_cat', $plugin_public, 'handle_klaviyo_viewed_pro_cat');
		$this->loader->add_action('wp_ajax_klaviyo_viewed_post', $plugin_public, 'handle_klaviyo_viewed_post');
		$this->loader->add_action('wp_ajax_nopriv_klaviyo_viewed_post', $plugin_public, 'handle_klaviyo_viewed_post');

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Klaviyo_Toolkit_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}
	
	/**
	 * Log messages if logging is enabled.
	 *
	 * @param string $message The message to log.
	 */
	public static function log_message($message) {
		$klaviyo_toolkit_logging = get_option('klaviyo_toolkit_logging');
		if ('enabled' === $klaviyo_toolkit_logging) {
			if (class_exists('WC_Logger')) {
				$logger = wc_get_logger();
				$context = array('source' => 'klaviyo-toolkit'); // Custom source for log entries
				$logger->info($message, $context);
			} else {
				error_log($message); // Fallback in case WC_Logger is not available
			}
		}
	}

}
