<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class KT_Klaviyo_Coupons {
	private $batch_size = 500; // Define the batch size as a class property

	public function __construct() {
		add_action('woocommerce_before_checkout_form', array($this, 'klaviyo_coupon_code_and_loggedin_profile_update'));
		add_action('wp_ajax_klaviyo_profile_update_generate_coupon', array($this, 'klaviyo_profile_update_generate_coupon'));
		add_action('wp_ajax_nopriv_klaviyo_profile_update_generate_coupon', array($this, 'klaviyo_profile_update_generate_coupon'));
	}

	public function klaviyo_coupon_code_and_loggedin_profile_update() {
		$current_user = wp_get_current_user();
		$current_username = $current_user->user_login;
		$current_user_email = $current_user->user_email;

		$klaviyo_abandoned_cart_coupon = get_option('klaviyo_abandoned_cart_coupon');

		if ('enabled' !== $klaviyo_abandoned_cart_coupon) {
			Klaviyo_Toolkit::log_message('Abandoned cart coupon is not enabled. Exiting function.');
			return;
		}

		// Auto generate coupon code
		$this->klaviyo_auto_generate_coupon_code($current_username, $current_user_email);

		// Update the customer profile in Klaviyo
		$this->klaviyo_update_customer_profile($current_user_email);
	}

	public function klaviyo_auto_generate_coupon_code($username, $user_email) {
		$klaviyo_coupon_amount = get_option('klaviyo_coupon_amount');
		$klaviyo_coupon_amount = !empty($klaviyo_coupon_amount) ? $klaviyo_coupon_amount : 0;
		$klaviyo_coupon_prefix = get_option('klaviyo_coupon_prefix');
		$klaviyo_coupon_prefix = !empty($klaviyo_coupon_prefix) ? $klaviyo_coupon_prefix : 'kt';

		// Generate a non-existing coupon code name
		if (is_user_logged_in()) {
			$coupon_code = $klaviyo_coupon_prefix . '-promo-' . $username . '-' . $klaviyo_coupon_amount;
		} else {
			$coupon_code = $klaviyo_coupon_prefix . '-' . $user_email . '-' . $klaviyo_coupon_amount;
		}

		if (wc_get_coupon_id_by_code($coupon_code)) {
			return;
		}

		// Get an empty instance of the WC_Coupon Object
		$coupon = new WC_Coupon();
		
		$klaviyo_coupon_type = get_option('klaviyo_coupon_type');
		$klaviyo_coupon_expiration = get_option('klaviyo_coupon_expiration');
		$klaviyo_coupon_expiration_days = !empty($klaviyo_coupon_expiration) ? $klaviyo_coupon_expiration : 0;
		
		// Only set expiration date if klaviyo_coupon_expiration_days is greater than 0
		if ($klaviyo_coupon_expiration_days > 0) {
			$current_date = date('Y-m-d', current_time('timestamp', 0));
			$klaviyo_coupon_expiration_date = date('Y-m-d', strtotime($current_date . ' + ' . $klaviyo_coupon_expiration_days . ' days'));
			$coupon->set_date_expires($klaviyo_coupon_expiration_date);
		}
		
		$klaviyo_coupon_used_with_other = get_option('klaviyo_coupon_used_with_other');
		$klaviyo_coupon_free_shipping = get_option('klaviyo_coupon_free_shipping');

		if ('percentage' === $klaviyo_coupon_type) {
			$discount_type = 'percent';
		} else {
			$discount_type = 'fixed_cart';
		}
		
		// Set the necessary coupon data (since WC 3+)
		$coupon->set_code($coupon_code);
		$coupon->set_amount($klaviyo_coupon_amount);
		$coupon->set_email_restrictions(array($user_email));
		$coupon->set_usage_limit(1);
		$coupon->set_individual_use(true);
		$coupon->set_description('Klaviyo Toolkit Plugin Coupon Generation');
		$coupon->set_discount_type($discount_type);
		// Create, publish and save coupon (data)
		$coupon->save();

		// Update individual coupon meta option
		$coupon_id = wc_get_coupon_id_by_code($coupon_code);
		update_post_meta($coupon_id, 'individual_use', ('no' === $klaviyo_coupon_used_with_other) ? 'yes' : 'no');
		update_post_meta($coupon_id, 'free_shipping', ('yes' === $klaviyo_coupon_free_shipping) ? 'yes' : 'no'); // Update Allow free shipping checkbox
	}

	public function klaviyo_update_customer_profile($user_email) {
		$secret_api_key = get_option('klaviyo_private_api_key');
		if (empty($secret_api_key)) {
			Klaviyo_Toolkit::log_message('Klaviyo secret API key is not set. Exiting function.');
			return;
		}

		$klaviyoService = new KT_Klaviyo_Service($secret_api_key);

		$clientProfileID = $klaviyoService->getProfileIdByEmail($user_email);
		if (!$clientProfileID) {
			Klaviyo_Toolkit::log_message('Profile not found for email: ' . $user_email);
			return;
		}

		$kt_coupon_amount = get_option('klaviyo_coupon_amount');
		$klaviyo_coupon_prefix = get_option('klaviyo_coupon_prefix');
		$klaviyo_coupon_prefix = !empty($klaviyo_coupon_prefix) ? $klaviyo_coupon_prefix : 'kt';

		// Generate a non-existing coupon code name
		if (is_user_logged_in()) {
			$current_user = wp_get_current_user();
			$current_username = $current_user->user_login;
			$coupon_code = $klaviyo_coupon_prefix . '-promo-' . $current_username . '-' . $kt_coupon_amount;
		} else {
			$coupon_code = $klaviyo_coupon_prefix . '-' . $user_email . '-' . $kt_coupon_amount;
		}

		$coupon = new WC_Coupon($coupon_code);
		$klaviyo_coupon_amount = $coupon->get_amount();

		$expiry_date = $coupon->get_date_expires();
		$expiry_time = $coupon->get_meta('expiry_time'); // Coupon custom field

		$body_params = array(
			'ac-coupon' => $coupon_code,
			'ac-coupon-amount' => $klaviyo_coupon_amount,
		);

		if ($expiry_date instanceof WC_DateTime) {
			$klaviyo_coupon_expiration = new WC_DateTime($expiry_date->date('Y-m-d') . ' ' . $expiry_time);
			$klaviyo_coupon_expiration_date = $klaviyo_coupon_expiration->format('m/d/Y');

			$body_params['ac-coupon-expiration'] = $klaviyo_coupon_expiration_date;
		}

		// Update the profile using the service class
		try {
			$klaviyoService->updateProfile($clientProfileID, $body_params);
		} catch (Exception $e) {
			Klaviyo_Toolkit::log_message('Error updating profile in Klaviyo: ' . $e->getMessage());
		}
	}

	public function klaviyo_profile_update_generate_coupon() {
		$billing_email = filter_input(INPUT_POST, 'billing_email', FILTER_SANITIZE_SPECIAL_CHARS);

		$klaviyo_abandoned_cart_coupon = get_option('klaviyo_abandoned_cart_coupon');

		if (!empty($billing_email) && is_email($billing_email) && 'enabled' === $klaviyo_abandoned_cart_coupon) {
			$current_user = wp_get_current_user();
			$current_username = !empty($current_user) ? $current_user->user_login : '';

			$this->klaviyo_auto_generate_coupon_code($current_username, $billing_email);

			// Update the customer profile in Klaviyo
			$this->klaviyo_update_customer_profile($billing_email);

			wp_send_json_success();
		} else {
			Klaviyo_Toolkit::log_message('Invalid billing email or abandoned cart coupon is not enabled.');
		}

		wp_die();
	}
}