<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class KT_Klaviyo_WC_Subscription_Events {
	private $klaviyoService;

	public function __construct($klaviyoService) {
		$this->klaviyoService = $klaviyoService;
		add_action('woocommerce_subscription_payment_complete', array($this, 'klaviyo_subscription_created'), 10, 1);
		add_action('woocommerce_subscription_status_updated', array($this, 'klaviyo_subscription_status_changed'), 10, 3);
		add_action('woocommerce_subscription_renewal_payment_complete', array($this, 'klaviyo_wc_subscription_renewal_payment'), 10, 2);
		add_action( 'woocommerce_subscription_renewal_payment_failed', array( $this, 'klaviyo_wc_subscription_renewal_payment' ), 10, 2 );
		add_action('woocommerce_subscriptions_switch_completed', array($this, 'klaviyo_wc_subscription_switched'), 10, 1);
	}
	
	/**
	 * WC Subscription Created Event
	 *
	 * @param $subscription
	 *
	 */
	public function klaviyo_subscription_created($subscription) {
		$parent_order_id = method_exists($subscription, 'get_parent_id') ? $subscription->get_parent_id() : $subscription->order->id;
		$related_orders_ids_array = $subscription->get_related_orders();
		$last_related_order_id = reset($related_orders_ids_array);
		if ($parent_order_id != $last_related_order_id) {
			Klaviyo_Toolkit::log_message('Parent order ID does not match last related order ID. Exiting function.');
			return;
		}
	
		$klaviyo_license_status = get_option('klaviyo_edd_license_status');
	
		$subscription_items = $subscription->get_items();
		$subscription_billing_interval = $subscription->get_billing_interval();
		$subscription_billing_period = $subscription->get_billing_period();
		$sub_full_billing_int = $subscription_billing_interval . ' ' . $subscription_billing_period;
	
		// WC subscription created event
		$klaviyo_wc_subscription_created = get_option('klaviyo_wc_subscription_created');
	
		if ('enabled' === $klaviyo_wc_subscription_created && 'valid' === $klaviyo_license_status) {
			foreach ($subscription_items as $item) {
				$is_trial = $this->is_trial($subscription);
				$subscription_id = $subscription->get_id();
				$sub_item_data = $item->get_data();
				$sub_item_variation_id = $sub_item_data['variation_id'];
				$sub_item_id = $sub_item_data['product_id'];
				$sub_product = wc_get_product($sub_item_id);
				$billing_period = WC_Subscriptions_Product::get_period($sub_product);
				$subscription_length = WC_Subscriptions_Product::get_length($sub_product);
	
				// If billing_period or subscription_length is empty and WCS_ATT_Order class exists
				if ((empty($billing_period) || empty($subscription_length)) && class_exists('WCS_ATT_Order')) {
					$subscription_scheme_key = WCS_ATT_Order::get_subscription_scheme($item);
					if ($subscription_scheme_key) {
						$subscription_schemes = WCS_ATT_Product_Schemes::get_subscription_schemes($sub_product);
						if (isset($subscription_schemes[$subscription_scheme_key])) {
							$subscription_scheme = $subscription_schemes[$subscription_scheme_key];
							$billing_period = $subscription_scheme->get_period();
							$subscription_length = $subscription_scheme->get_interval();
						}
					}
				}
	
				$ranges = wcs_get_subscription_ranges($billing_period);
				$product_feat_img_url = wp_get_attachment_url(get_post_thumbnail_id($sub_item_id));
	
				$planExpiresAfter = isset($ranges[$subscription_length]) ? $ranges[$subscription_length] : '';
				$planGifted = 'no';
				$subscription_email = $subscription->get_billing_email();
	
				if (class_exists('WCS_Gifting')) {
					$klaviyo_change_email_to_recipient = get_option('klaviyo_change_email_to_recipient');
					if ('enabled' === $klaviyo_change_email_to_recipient && WCS_Gifting::is_gifted_subscription($subscription)) {
						$recipient_user_id = WCS_Gifting::get_recipient_user($subscription);
						$recipient_user = get_userdata($recipient_user_id);
						$subscription_email = $recipient_user->user_email;
						$planGifted = 'yes';
					}
				}
	
				$wc_sub_created_array = array(
					'PlanName' => $item->get_name(),
					'SubID' => $subscription_id,
					'PlanID' => $sub_item_id,
					'PlanTrial' => $is_trial ? 'True' : 'False',
					'PlanTrialEndDate' => $subscription->get_date('trial_end'),
					'PlanExpirationDate' => $subscription->get_date('schedule_end'),
					'$value' => $is_trial ? 0 : $subscription->get_total(),
					'PlanInterval' => $sub_full_billing_int,
					'PlanNextPaymentDate' => $subscription->get_date_to_display('next_payment'),
					'PlanExpiresAfter' => $planExpiresAfter,
					'PlanGifted' => $planGifted
				);
	
				if (!empty($sub_item_variation_id)) {
					$wc_sub_created_array['PlanVariationID'] = $sub_item_variation_id;
				}
	
				if (!empty($product_feat_img_url)) {
					$wc_sub_created_array['ProductImage'] = $product_feat_img_url;
				}
	
				// Add filter hook
				$wc_sub_created_array = apply_filters('tribe_klaviyo_sub_created_event', $wc_sub_created_array, $subscription);
	
				try {
					$this->klaviyoService->sendEvent(array(
						'properties' => $wc_sub_created_array,
						'metric_name' => 'WC Subscription Created',
						'customer_properties' => array(
							'$email' => $subscription_email
						)
					));
				} catch (Exception $e) {
					Klaviyo_Toolkit::log_message('Error sending subscription created event to Klaviyo: ' . $e->getMessage());
				}
	
				// Check if variation ID exists and use it as the product key
				$product_key = 'wc-sub-product-' . (!empty($sub_item_variation_id) ? $sub_item_variation_id : $sub_item_id);
				$custom_profile_param = array(
					$product_key => $subscription->get_status()
				);
	
				try {
					$this->klaviyoService->updateProfileByEmail($subscription_email, $custom_profile_param);
				} catch (Exception $e) {
					Klaviyo_Toolkit::log_message('Error updating profile in Klaviyo for email: ' . $subscription_email . ' - ' . $e->getMessage());
				}
			}
		} else {
			Klaviyo_Toolkit::log_message('Subscription created is not enabled or the license is not valid.');
		}
	}
	
	/**
	 * WC Subscription Status Changed Event
	 *
	 * @param $subscription
	 * @param $new_status
	 * @param $old_status
	 */
	public function klaviyo_subscription_status_changed($subscription, $new_status, $old_status) {
		// Proceed if old status is not pending
		if ('pending' !== $old_status) {
			$klaviyo_license_status = get_option('klaviyo_edd_license_status');
			$klaviyo_wc_subscription_status_change = get_option('klaviyo_wc_subscription_status_change');
	
			if ('enabled' === $klaviyo_wc_subscription_status_change && 'valid' === $klaviyo_license_status) {
				$subscription_items = $subscription->get_items();
	
				if (!empty($subscription_items)) {
					foreach ($subscription_items as $sub_item) {
						$sub_item_data = $sub_item->get_data();
						$subscription_plan = $sub_item_data['name'];
						$subscription_plan_id = $sub_item_data['product_id'];
						$sub_item_variation_id = $sub_item_data['variation_id'];
						$subscription_value = $sub_item_data['total'];
						$product_feat_img_url = wp_get_attachment_url(get_post_thumbnail_id($subscription_plan_id));
	
						$wc_status_changed_event_array = array(
							'WC Subscription Status Changed Value' => $subscription_value,
							'PlanName' => $subscription_plan,
							'PlanID' => $subscription_plan_id,
							'PlanValue' => $subscription_value,
							'PlanStatus' => $new_status
						);
	
						if (!empty($sub_item_variation_id)) {
							$wc_status_changed_event_array['PlanVariationID'] = $sub_item_variation_id;
						}
	
						if ('cancelled' === $new_status || 'pending-cancel' === $new_status) {
							$wc_status_changed_event_array['Subscription End Date'] = $subscription->get_date('end_date');
						}
	
						if (!empty($product_feat_img_url)) {
							$wc_status_changed_event_array['ProductImage'] = $product_feat_img_url;
						}
	
						// Send event to Klaviyo
						try {
							$this->klaviyoService->sendEvent(array(
								'properties' => $wc_status_changed_event_array,
								'metric_name' => 'WC Subscription Status Changed',
								'customer_properties' => array(
									'$email' => $subscription->get_billing_email()
								)
							));
						} catch (Exception $e) {
							Klaviyo_Toolkit::log_message('Error sending subscription status changed event to Klaviyo: ' . $e->getMessage());
						}
	
						// Set the custom profile field for the plan status
						$product_key = 'wc-sub-product-' . (!empty($sub_item_variation_id) ? $sub_item_variation_id : $subscription_plan_id);
						$custom_profile_param = array(
							$product_key => $subscription->get_status()
						);
	
						// Update the status field in Klaviyo
						try {
							$this->klaviyoService->updateProfileByEmail($subscription->get_billing_email(), $custom_profile_param);
						} catch (Exception $e) {
							Klaviyo_Toolkit::log_message('Error updating profile in Klaviyo for email: ' . $subscription->get_billing_email() . ' - ' . $e->getMessage());
						}
					}
				} else {
					Klaviyo_Toolkit::log_message('No subscription items found.');
				}
			} else {
				Klaviyo_Toolkit::log_message('Subscription status change is not enabled or the license is not valid.');
			}
		}
	}
	
	/**
	 * WC Subscription Renewal Event
	 *
	 * @param $subscription
	 * @param $last_order
	 */
	public function klaviyo_wc_subscription_renewal_payment($subscription, $last_order) {
		$klaviyo_license_status = get_option('klaviyo_edd_license_status');
		$klaviyo_wc_subscription_renewal = get_option('klaviyo_wc_subscription_renewal');
	
		if ('enabled' === $klaviyo_wc_subscription_renewal && 'valid' === $klaviyo_license_status) {
			$subscription_items = $subscription->get_items();
			$last_renewal_order_status = $last_order->get_status();
	
			$subscription_renewal_status = 'Success';
			if ('failed' === $last_renewal_order_status) {
				$subscription_renewal_status = 'Fail';
			}
	
			$subscription_billing_interval = $subscription->get_billing_interval();
			$subscription_billing_period = $subscription->get_billing_period();
			$sub_full_billing_int = $subscription_billing_interval . ' ' . $subscription_billing_period;
			$subscription_id = $subscription->get_id(); // Real plan ID
	
			if (!empty($subscription_items)) {
				foreach ($subscription_items as $sub_item) {
					$sub_item_data = $sub_item->get_data();
					$subscription_plan = $sub_item_data['name'];
					$subscription_plan_id = $sub_item_data['product_id']; // Product ID
					$sub_item_variation_id = $sub_item_data['variation_id']; // Variation ID
					$subscription_value = $sub_item_data['total'];
					$product_feat_img_url = wp_get_attachment_url(get_post_thumbnail_id($subscription_plan_id));
	
					// Get the renewal count
					$renewal_count = $this->get_total_subscription_renewals($subscription_id);
	
					$wc_sub_renewal_array = array(
						'WC Subscription Renewal Value' => $subscription_value,
						'SubID' => $subscription_id,
						'PlanName' => $subscription_plan,
						'PlanID' => $subscription_plan_id,
						'PlanValue' => $subscription_value,
						'PlanRenewalStatus' => $subscription_renewal_status,
						'PlanInterval' => $sub_full_billing_int,
						'SubTotalOrders' => $renewal_count,
						'NextPaymentDate' => $subscription->get_date_to_display('next_payment'),
					);
	
					if (!empty($sub_item_variation_id)) {
						$wc_sub_renewal_array['PlanVariationID'] = $sub_item_variation_id;
					}
	
					if (!empty($product_feat_img_url)) {
						$wc_sub_renewal_array['ProductImage'] = $product_feat_img_url;
					}
	
					// Send event to Klaviyo
					try {
						$this->klaviyoService->sendEvent(array(
							'properties' => $wc_sub_renewal_array,
							'metric_name' => 'WC Subscription Renewal',
							'customer_properties' => array(
								'$email' => $subscription->get_billing_email()
							)
						));
					} catch (Exception $e) {
						Klaviyo_Toolkit::log_message('Error sending subscription renewal event to Klaviyo: ' . $e->getMessage());
					}
				}
			} else {
				Klaviyo_Toolkit::log_message('No subscription items found.');
			}
		} else {
			Klaviyo_Toolkit::log_message('Subscription renewal is not enabled or the license is not valid.');
		}
	}
	
	/**
	 * WC Susbcription Switched Event
	 *
	 * @param $order
	 */
	public function klaviyo_wc_subscription_switched($order) {
		$klaviyo_license_status = get_option('klaviyo_edd_license_status');
		$klaviyo_wc_subscription_switched = get_option('klaviyo_wc_subscription_switched');
	
		// Ensure order is an object and get the ID
		if (is_object($order)) {
			$order_id = $order->get_id();
		} else {
			$order_id = (int) $order;
		}
	
		if ('enabled' === $klaviyo_wc_subscription_switched && 'valid' === $klaviyo_license_status) {
			$order = wc_get_order($order_id);
			$subscriptions = wcs_get_subscriptions_for_order($order_id);
	
			$subscription = end($subscriptions);
	
			if (!$subscription) {
				Klaviyo_Toolkit::log_message('No subscription found for order_id: ' . $order_id);
				return;
			}
	
			$customer_email = $subscription->get_billing_email();
			$subscription_id = $subscription->get_id();
			$value = $subscription->get_total();	
			$billing_interval = $subscription->get_billing_interval();
			$billing_period = $subscription->get_billing_period();
			$plan_interval = $billing_interval . ' ' . $billing_period;
	
			$next_payment_date = $subscription->get_date('next_payment');
			$subscription_link = wc_get_endpoint_url('view-subscription', $subscription_id, wc_get_page_permalink('myaccount'));
	
			$new_order_items = $order->get_items();
			$new_order_item = reset($new_order_items);
			$new_product = $new_order_item->get_product();
			$new_plan_name = $new_product->get_name();
			$new_product_image = wp_get_attachment_image_src($new_product->get_image_id(), 'full')[0] ?? '';
			$new_product_link = get_permalink($new_product->get_id());
			$new_var_name = $this->get_variation_name($new_product, $new_order_item);
	
			$related_orders = $subscription->get_related_orders('ids', array('parent', 'renewal', 'switch'));
	
			array_pop($related_orders);
			$orderedIds = array_values($related_orders);
	
			if (count($orderedIds) < 2) {
				Klaviyo_Toolkit::log_message('Not enough related orders found for subscription ' . $subscription_id);
				return;
			}
	
			$previous_order_index = 1;
			$previous_order_id = $orderedIds[$previous_order_index];
			$previous_order = wc_get_order($previous_order_id);
	
			$old_plan_name = '';
			$old_var_name = '';
			$old_product_image = '';
			$old_product_link = '';
	
			if ($previous_order && is_a($previous_order, 'WC_Order')) {
				$previous_items = $previous_order->get_items();
				$previous_item = end($previous_items);
	
				$previous_product = $previous_item->get_product();
	
				$old_plan_name = $previous_product->get_name();
				$old_product_image = wp_get_attachment_image_src($previous_product->get_image_id(), 'full')[0] ?? '';
				$old_product_link = get_permalink($previous_product->get_id());
				$old_var_name = $this->get_variation_name($previous_product, $previous_item);
	
			} else {
				Klaviyo_Toolkit::log_message("Order with ID: $previous_order_id not found or is not a valid WC_Order");
			}
	
			$switch_event_details = array(
				'SubID' => $subscription_id,
				'SubInterval' => $plan_interval,
				'SubNextPaymentDate' => $next_payment_date,
				'SubManageLink' => $subscription_link,
				'OldProductName' => $old_plan_name,
				'OldProductVarName' => $old_var_name,
				'OldProductImage' => $old_product_image,
				'OldProductLink' => $old_product_link,
				'NewProductName' => $new_plan_name,
				'NewProductVarName' => $new_var_name,
				'NewProductImage' => $new_product_image,
				'NewProductLink' => $new_product_link,
				'$value' => $value
			);
	
			// Send event to Klaviyo
			try {
				$this->klaviyoService->sendEvent(array(
					'properties' => $switch_event_details,
					'metric_name' => 'WC Subscription Switched',
					'customer_properties' => array(
						'$email' => $customer_email
					)
				));
			} catch (Exception $e) {
				Klaviyo_Toolkit::log_message('Error sending subscription switched event to Klaviyo: ' . $e->getMessage());
			}
		} else {
			Klaviyo_Toolkit::log_message('Subscription switched is not enabled or the license is not valid.');
		}
	}
	
	private function get_variation_name($product, $item) {
		if ($product->is_type('variation')) {
			// Fetch metadata from the order item
			$item_data = $item->get_meta_data();
	
			$exclude_keys = [
				'_switched_subscription_sign_up_fee_prorated',
				'_switched_subscription_price_prorated',
				'_cart_item_key_subscription_switch'
			];
	
			$variation_data = [];
			foreach ($item_data as $data) {
				if (strpos($data->key, 'attribute_') === 0) {
					$variation_data[str_replace('attribute_', '', $data->key)] = $data->value;
				} elseif (strpos($data->key, 'pa_') === 0) {
					$variation_data[str_replace('pa_', '', $data->key)] = $data->value;
				} elseif (!in_array($data->key, $exclude_keys)) {
					if (strpos($data->key, '-') !== false) {
						$exploded_data = explode('-', $data->key);
						$variation_data[end($exploded_data)] = $data->value;
					} else {
						$variation_data[$data->key] = $data->value;
					}
				}
			}
	
			// Construct variation name
			$var_name = '';
			foreach ($variation_data as $attribute => $value) {
				$var_name .= ucfirst($attribute) . ': ' . $value . ', ';
			}
	
			return rtrim($var_name, ', ');
		}
	
		return '';
	}
	
	private function get_total_subscription_renewals($subscription_id) {
		// Ensure WooCommerce Subscriptions is active
		if (!function_exists('wcs_get_subscription')) {
			return 0;
		}
	
		// Get the subscription object
		$subscription = wcs_get_subscription($subscription_id);
	
		// Check if the subscription exists
		if (!$subscription) {
			return 0;
		}
	
		// Get related orders for the subscription
		$related_orders_ids = $subscription->get_related_orders('ids', 'renewal');
	
		// Count the number of related orders
		$total_renewals = count($related_orders_ids);
	
		return $total_renewals;
	}

	private function is_trial($subscription) {
		// Logic to determine if the subscription is in a trial period
		$trial_end_date = $subscription->get_date('trial_end');
		return !empty($trial_end_date) && strtotime($trial_end_date) > time();
	}
	
	
}
