<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://madebytribe.com
 * @since      1.0.0
 *
 * @package    Klaviyo_Toolkit
 * @subpackage Klaviyo_Toolkit/public
 */

class KT_Public {

	private $plugin_name;
	private $version;
	private $klaviyoService;
	private $klaviyoMetricEvents;
	private $klaviyoSubscriptions;
	private $klaviyoCoupons;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		$this->load_dependencies();

		add_filter('woocommerce_billing_fields', array($this, 'klaviyo_move_checkout_email_above_name_fields'), 10, 1);

	}

	/**
	 * Load the required dependencies for this class.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {
		require_once plugin_dir_path(__FILE__) . '../includes/klaviyo/class-kt-klaviyo-service.php';
		require_once plugin_dir_path(__FILE__) . '../includes/klaviyo/class-kt-klaviyo-general-events.php';
		require_once plugin_dir_path(__FILE__) . '../includes/klaviyo/class-kt-klaviyo-wc-sub-events.php';
		require_once plugin_dir_path(__FILE__) . '../includes/klaviyo/class-kt-klaviyo-coupons.php';
		
		$apiKey = get_option('klaviyo_private_api_key');
		$this->klaviyoService = new KT_Klaviyo_Service($apiKey);
		$this->klaviyoMetricEvents = new KT_Klaviyo_General_Events($this->klaviyoService);
		$this->klaviyoSubscriptions = new KT_Klaviyo_WC_Subscription_Events($this->klaviyoService);
		$this->klaviyoCoupons = new KT_Klaviyo_Coupons($this->klaviyoService);
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/kt-public.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/kt-public.js', array( 'jquery' ), $this->version, false );

		$params = array(
			'ajaxurl' => admin_url('admin-ajax.php'),
		);
		wp_localize_script( $this->plugin_name, 'klaviyoPublicAjax', $params );

		// Get options
		$klaviyo_viewed_page = get_option('klaviyo_viewed_page');
		$klaviyo_searched_site = get_option('klaviyo_searched_site');
		$klaviyo_viewed_pro_cat = get_option('klaviyo_viewed_pro_cat');
		$klaviyo_viewed_post = get_option('klaviyo_viewed_post');
		$klaviyo_license_status = get_option('klaviyo_edd_license_status');

		// Only enqueue script if license is valid
		if ('valid' === $klaviyo_license_status) {
			wp_enqueue_script('klaviyo-general-events', plugin_dir_url(__FILE__) . 'js/kt-general-events.js', array('jquery'), '1.0', true);

			wp_localize_script('klaviyo-general-events', 'klaviyoPublicAjax', array(
				'ajaxurl' => admin_url('admin-ajax.php'),
				'user_email' => wp_get_current_user()->user_email,
				'klaviyo_viewed_page_enabled' => 'enabled' === $klaviyo_viewed_page,
				'klaviyo_searched_site_enabled' => 'enabled' === $klaviyo_searched_site,
			));

			// Localize script for viewed product category event
			if (is_product_category() && 'enabled' === $klaviyo_viewed_pro_cat) {
				$queried_object = get_queried_object();
				$categoryID = $queried_object->term_taxonomy_id;
				$categoryName = $queried_object->name;
				$cat_thumb_image_url = '';
				$cat_thumbnail_id = get_term_meta($categoryID, 'thumbnail_id', true);
				if (!empty($cat_thumbnail_id)) {
					$cat_thumb_image_url = wp_get_attachment_url($cat_thumbnail_id);
				}
				wp_localize_script('klaviyo-general-events', 'klaviyoPublicAjax', array(
					'ajaxurl' => admin_url('admin-ajax.php'),
					'user_email' => wp_get_current_user()->user_email,
					'klaviyo_viewed_pro_cat_enabled' => true,
					'categoryID' => $categoryID,
					'categoryName' => $categoryName,
					'imageURL' => $cat_thumb_image_url,
				));
			}

			// Localize script for viewed post event
			if (is_single() && 'enabled' === $klaviyo_viewed_post) {
				global $post;
				$postID = $post->ID;
				$postTitle = get_the_title($postID);
				$postCategories = get_the_category($postID);
				$postCategoriesArray = array();
				if (!empty($postCategories)) {
					foreach ($postCategories as $postCategory) {
						$postCategoriesArray[] = $postCategory->name;
					}
				}
				$postCategoriesString = implode(",", $postCategoriesArray);
				$postImageURL = has_post_thumbnail($postID) ? get_the_post_thumbnail_url($postID, 'full') : '';
				wp_localize_script('klaviyo-general-events', 'klaviyoPublicAjax', array(
					'ajaxurl' => admin_url('admin-ajax.php'),
					'user_email' => wp_get_current_user()->user_email,
					'klaviyo_viewed_post_enabled' => true,
					'postID' => $postID,
					'postTitle' => $postTitle,
					'postCategories' => $postCategoriesString,
					'imageURL' => $postImageURL,
				));
			}
		}

	}

	public function klaviyo_add_imgs_to_rss_feeds() {
		$klaviyo_license_status = get_option('klaviyo_edd_license_status');
		$klaviyo_add_imgs_to_rss = get_option('klaviyo_add_imgs_to_rss');
		if ('enabled' === $klaviyo_add_imgs_to_rss && 'valid' === $klaviyo_license_status) {
			global $post;
			if (has_post_thumbnail($post->ID)) {
				$output = '';
				$post_thumbnail_id = get_post_thumbnail_id($post->ID);
				$thumbnail = wp_get_attachment_image_src($post_thumbnail_id, 'full');
				$output .= '<image>';
				$output .= $thumbnail[0];
				$output .= '</image>';
				echo $output;
			}
		}
	}
	
	public function klaviyo_move_checkout_email_above_name_fields($address_fields) {
		$klaviyo_license_status = get_option('klaviyo_edd_license_status');
		$klaviyo_email_above_name_fields = get_option('klaviyo_email_above_name_fields');
	
		if ('enabled' === $klaviyo_email_above_name_fields && 'valid' === $klaviyo_license_status) {
			$address_fields['billing_email']['priority'] = 5;
		}
	
		return $address_fields;
	}
	
	public function handle_klaviyo_viewed_page() {
		$url = sanitize_text_field($_POST['url']);
		$page_id = url_to_postid($url);
	
		if ($page_id) {
			$page_title = get_the_title($page_id);
		} else {
			$page_id = 0;
			$page_title = 'Unknown Page';
		}
	
		$pageDetails = array(
			'url' => $url,
			'id' => $page_id,
			'title' => $page_title,
			'email' => sanitize_email($_POST['email']),
		);
	
		try {
			$this->klaviyoMetricEvents->sendViewedPageEvent($pageDetails);
			wp_send_json_success('Event received');
		} catch (Exception $e) {
			Klaviyo_Toolkit::log_message('Error handling viewed page: ' . $e->getMessage());
			wp_send_json_error('Error occurred');
		}
	
		wp_die();
	}
	
	public function handle_klaviyo_searched_site() {
		$search_query = sanitize_text_field($_POST['query']);
		$search_results = new WP_Query(array('s' => $search_query));
		$total_search_results = $search_results->found_posts;
		$search_results_url = site_url() . '/?s=' . urlencode($search_query);
	
		$searchDetails = array(
			'query' => $search_query,
			'total_results' => $total_search_results,
			'results_url' => $search_results_url,
			'email' => sanitize_email($_POST['email']),
		);
	
		try {
			$this->klaviyoMetricEvents->sendSearchedSiteEvent($searchDetails);
			wp_send_json_success('Event received');
		} catch (Exception $e) {
			Klaviyo_Toolkit::log_message('Error handling site search: ' . $e->getMessage());
			wp_send_json_error('Error occurred');
		}
	
		wp_die();
	}
	
	public function handle_klaviyo_viewed_pro_cat() {
		$categoryDetails = array(
			'categoryID' => sanitize_text_field($_POST['categoryID']),
			'categoryName' => sanitize_text_field($_POST['categoryName']),
			'imageURL' => sanitize_text_field($_POST['imageURL']),
			'url' => sanitize_text_field($_POST['url']),
			'email' => sanitize_email($_POST['email']),
		);
	
		try {
			$this->klaviyoMetricEvents->sendViewedProductCategoryEvent($categoryDetails);
			wp_send_json_success('Event received');
		} catch (Exception $e) {
			Klaviyo_Toolkit::log_message('Error handling viewed product category: ' . $e->getMessage());
			wp_send_json_error('Error occurred');
		}
	
		wp_die();
	}
	
	public function handle_klaviyo_viewed_post() {
		$postDetails = array(
			'postID' => sanitize_text_field($_POST['postID']),
			'postTitle' => sanitize_text_field($_POST['postTitle']),
			'postCategories' => sanitize_text_field($_POST['postCategories']),
			'imageURL' => sanitize_text_field($_POST['imageURL']),
			'url' => sanitize_text_field($_POST['url']),
			'email' => sanitize_email($_POST['email']),
		);
	
		try {
			$this->klaviyoMetricEvents->sendViewedPostEvent($postDetails);
			wp_send_json_success('Event received');
		} catch (Exception $e) {
			Klaviyo_Toolkit::log_message('Error handling viewed post: ' . $e->getMessage());
			wp_send_json_error('Error occurred');
		}
	
		wp_die();
	}

}